@@ -721,14 +721,14 @@ _SEQDB = {
     '> CSI $x'           : 'DECFRA / fill rectangular area',
     '> CSI \'z'          : 'DECELR / enable locator reporting ',
     '> CSI $z'           : 'DECERA / erase rectangular area',
-    '> CSI [4]$z'        : 'DECErA / erase rectangular area - top=%s, left=%s, bottom=%s, right=%s',
+    '> CSI [4]$z'        : 'DECERA / erase rectangular area - top=%s, left=%s, bottom=%s, right=%s',
     '> CSI `$'           : 'DECSLE / select locator events',
-    '> CSI [0]`$'        : 'DECSLE 0 / select locator events: only respond to explicit host requests',
-    '> CSI 0`$'          : 'DECSLE 0 / select locator events: only respond to explicit host requests',
-    '> CSI 1`$'          : 'DECSLE 1 / select locator events: report button down transitions',
-    '> CSI 2`$'          : 'DECSLE 2 / select locator events: do not report button down transitions',
-    '> CSI 3`$'          : 'DECSLE 3 / select locator events: report button up transitions',
-    '> CSI 4`$'          : 'DECSLE 4 / select locator events: do not report button up transitions',
+    '> CSI [0]`{'        : 'DECSLE 0 / select locator events: only respond to explicit host requests',
+    '> CSI 0`{'          : 'DECSLE 0 / select locator events: only respond to explicit host requests',
+    '> CSI 1`{'          : 'DECSLE 1 / select locator events: report button down transitions',
+    '> CSI 2`{'          : 'DECSLE 2 / select locator events: do not report button down transitions',
+    '> CSI 3`{'          : 'DECSLE 3 / select locator events: report button up transitions',
+    '> CSI 4`{'          : 'DECSLE 4 / select locator events: do not report button up transitions',
     '> CSI ${'           : 'DECSERA / selective erase rectangular area',
     '> CSI [4]${'        : 'DECSERA / selective erase rectangular area (%s, %s, %s, %s)',
     '> CSI `|'           : 'DECRQLP / request locator position',
